pub fn has_errors(msgs: &[Message]) -> boolExpand description
Returns true if any message in msgs has level MessageLevel::Error.
pub fn has_errors(msgs: &[Message]) -> boolReturns true if any message in msgs has level MessageLevel::Error.