pub struct BodyRule {
pub pattern: Arc<Regex>,
pub optional: bool,
pub repeat: bool,
}Fields
pattern: Arc<Regex>optional: boolIf true, this rule may be skipped if the line does not match.
repeat: boolIf true, this rule may match zero or more consecutive lines.