Module format

Module format 

Format-specific cursor context detectors.

Each sub-module is responsible for parsing a specific file format and converting a (buffer, cursor) pair into a CursorContext.

Add new sub-modules here when adding YAML/JSON/etc. support.

Modules

json
JSON cursor context detection — stub (not yet implemented).
toml
TOML cursor context detection using tree-sitter.
yaml
YAML cursor context detection.

Functions

detect_cursor_context
Detect the cursor context for the file at path.