pub struct ConfigError {
pub path: String,
pub message: String,
}Expand description
A validation error produced while loading or validating a tasks.yaml.
Fields
path: StringDot-separated path to the field that caused the error
(e.g. "tasks.build.inputs.mode.options").
message: StringHuman-readable description of the problem.